package PagSeguro::API::Payment::Sender;
use Moo;

has name  => (is => 'rw');
has email => (is => 'rw');
has area_code => (is => 'rw');
has phone => (is => 'rw');

1;
__END__

=encodind utf8

=head1 NAME

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 METHODS

=head2 
